//
//  NoodleRowSpanningTableView.h
//  NoodleRowSpanningTableViewTest
//
//  Created by Paul Kim on 10/20/09.
//  Copyright 2009 Noodlesoft, LLC. All rights reserved.
//
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following
// conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.

#import <Cocoa/Cocoa.h>

/*
 Provides support for spanning rows, which are cells in a column that span across multiple rows. For any columns
 where you want to have this take effect, just change the column class to NoodleRowSpanningTableColumn.
 */
@interface NoodleRowSpanningTableView : NSTableView
{
}

- (NSRange)rangeOfRowSpanAtColumn:(NSInteger)columnIndex row:(NSInteger)rowIndex;

@end

@interface NSTableColumn (NoodleRowSpanning)

// Returns whether this column will try to consolidate rows into spans.
- (BOOL)isRowSpanningEnabled;

@end


@class NoodleRowSpanningCell;

/*
 Special table column that enables row spanning functionality. Just set your columns in IB to use this class.
 */
@interface NoodleRowSpanningTableColumn :NSTableColumn
{
	BOOL						_spanningEnabled;
	NoodleRowSpanningCell		*_cell;

}

@property (getter=isRowSpanningEnabled, setter=setRowSpanningEnabled:) BOOL rowSpanningEnabled;

@end
